@@ -19,9 +19,10 @@
 # ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE
 # OR PERFORMANCE OF THIS SOFTWARE!
 import math
+import numpy as np
 
 import matplotlib.pyplot as plt
-import numpy as np
+
 import pyAgrum as gum
 
 
@@ -33,12 +34,12 @@ def _stats(pot):
     x = v.numerical(i)
     mu += p * x
     mu2 += p * x * x
-  return (mu, math.sqrt(mu2 - mu * mu))
+  return mu, math.sqrt(mu2 - mu * mu)
 
 
-def _getTitleHisto(p, showMuSigma=True):
+def _getTitleHisto(p, show_mu_sigma=True):
   var = p.variable(0)
-  if var.varType() == 1 or not showMuSigma:  # Labelized
+  if var.varType() == 1 or not show_mu_sigma:  # type=1 is for gum.LabelizedVariable
     return var.name()
 
   (mu, std) = _stats(p)
@@ -106,23 +107,27 @@ def _getProbaLine(p, scale=1.0, txtcolor="black"):
   """
 
   var = p.variable(0)
-  if gum.config['notebook', 'histogram_mode'] == "compact":
-    ra, v, lv = __limits(p)
+  #if gum.config['notebook', 'histogram_mode'] == "compact":
+  #  ra, v, lv = __limits(p)
+  #else:
+  lv = [var.label(int(i)) for i in np.arange(var.domainSize())]
+  v = p.tolist()
+  ra=range(var.domainSize())
+  if var.domainSize()>15:
+    step=int(var.domainSize()/15)
   else:
-    lv = [var.label(int(i)) for i in np.arange(var.domainSize())]
-    v = p.tolist()
-    ra = range(len(v))
+    step=1
 
   fig = plt.figure()
   fig.set_figwidth(min(scale * 6, scale * len(v) / 4.0))
   fig.set_figheight(scale * 2)
 
   ax = fig.add_subplot(111)
+  ax.set_xticks(ra[::step])
+  ax.set_xticklabels(lv[::step],rotation='vertical')
   ax.fill_between(ra, v, color=gum.config['notebook', 'histogram_color'])
 
   ax.set_ylim(bottom=0, top=1.05 * p.max())
-  # ax.set_xticks(ra)
-  # ax.set_xticklabels(lv, color=txtcolor)
   ax.set_title(_getTitleHisto(p, True), color=txtcolor)
 
   ax.get_xaxis().grid(True)
@@ -130,7 +135,6 @@ def _getProbaLine(p, scale=1.0, txtcolor="black"):
   ax.margins(0)
 
   ax.set_facecolor('w')
-
   return fig
 
 
@@ -193,7 +197,7 @@ def _getProbaV(p, scale=1.0, util=None, txtcolor="black"):
   ax.set_ylim(bottom=0, top=p.max())
   ax.set_xticks(ra)
   ax.set_xticklabels(lv, rotation='vertical', color=txtcolor)
-  # if utility, we do not show the mean/sigma of the proba.
+  # if utility, we do not show the mean/sigma of the distribution.
   ax.set_title(_getTitleHisto(p, util is None), color=txtcolor)
   ax.get_yaxis().grid(True)
   ax.margins(0)
@@ -204,12 +208,13 @@ def _getProbaV(p, scale=1.0, util=None, txtcolor="black"):
 
 def _getProbaH(p, scale=1.0, util=None, txtcolor="black"):
   """
-  compute the representation of an horizontal histogram for a mono-dim Potential
+  compute the representation of a horizontal histogram for a mono-dim Potential
 
   Parameters
   ----------
     p : pyAgrum.Potential
       the mono-dimensional Potential
+    scale : scale for the size of the graph
     util : pyAgrum.Potential
       an (optional) secondary Potential (values in labels)
     txtcolor : str
@@ -265,7 +270,7 @@ def _getProbaH(p, scale=1.0, util=None, txtcolor="black"):
   ax.set_yticklabels(vx, color=txtcolor)
   ax.set_xticklabels([])
   # ax.set_xlabel('Probability')
-  # if utility, we do not show the mean/sigma of the proba.
+  # if utility, we do not show the mean/sigma of the distribution.
   ax.set_title(_getTitleHisto(p, util is None), color=txtcolor)
   ax.get_xaxis().grid(True)
   ax.margins(0)
@@ -275,12 +280,14 @@ def _getProbaH(p, scale=1.0, util=None, txtcolor="black"):
 
 def proba2histo(p, scale=1.0, util=None, txtcolor="Black"):
   """
-  compute the representation of an histogram for a mono-dim Potential
+  compute the representation of a histogram for a mono-dim Potential
 
   Parameters
   ----------
     p : pyAgrum.Potential
       the mono-dimensional Potential
+    scale : float
+      scale for the size of the graph
     util : pyAgrum.Potential
       an (optional) secondary Potential (values in labels)
     txtcolor : str
@@ -303,14 +310,16 @@ def proba2histo(p, scale=1.0, util=None, txtcolor="Black"):
   return _getProbaH(p, scale, util=util, txtcolor=txtcolor)
 
 
-def saveFigProba(p, filename, util=None, bgcol=None, txtcolor="Black"):
+def saveFigProba(p, filename, util=None, bgcolor=None, txtcolor="Black"):
   """
-  save a figure  which is the representation of an histogram for a mono-dim Potential
+  save a figure  which is the representation of a histogram for a mono-dim Potential
 
   Parameters
   ----------
     p : pyAgrum.Potential
       the mono-dimensional Potential
+    filename: str
+      the name of the saved file
     util : pyAgrum.Potential
       an (optional) secondary Potential (values in labels)
     bgcolor: str
@@ -320,10 +329,10 @@ def saveFigProba(p, filename, util=None, bgcol=None, txtcolor="Black"):
   """
   fig = proba2histo(p, util=util, txtcolor=txtcolor)
 
-  if bgcol is None:
+  if bgcolor is None:
     fc = gum.config["notebook", "figure_facecolor"]
   else:
-    fc = bgcol
+    fc = bgcolor
 
   fig.savefig(filename, bbox_inches='tight', transparent=False, facecolor=fc,
               pad_inches=0.05, dpi=fig.dpi, format=gum.config["notebook", "graph_format"])
@@ -332,12 +341,14 @@ def saveFigProba(p, filename, util=None, bgcol=None, txtcolor="Black"):
 
 def probaMinMaxH(pmin, pmax, scale=1.0, txtcolor="black"):
   """
-  compute the representation of an horizontal histogram for a mono-dim Potential
+  compute the representation of a horizontal histogram for a mono-dim Potential
 
   Parameters
   ----------
     pmin,pmax : pyAgrum.Potential
       two mono-dimensional Potential
+    scale : float
+      scale for the size of the graph
     txtcolor : str
       color for text
 
@@ -395,9 +406,9 @@ def probaMinMaxH(pmin, pmax, scale=1.0, txtcolor="black"):
   return fig
 
 
-def saveFigProbaMinMax(pmin, pmax, filename, bgcol=None, txtcolor="Black"):
+def saveFigProbaMinMax(pmin, pmax, filename, bgcolor=None, txtcolor="Black"):
   """
-  save a figure  which is the representation of an histogram for a bi-Potential (min,max)
+  save a figure  which is the representation of a histogram for a bi-Potential (min,max)
 
   Parameters
   ----------
@@ -405,6 +416,8 @@ def saveFigProbaMinMax(pmin, pmax, filename, bgcol=None, txtcolor="Black"):
       the mono-dimensional Potential for min values
     pmax : pyAgrum.Potential
       the mono-dimensional Potential for max value
+    filename : str
+      the name of the saved file
     bgcolor: str
       color for background (transparent if None)
     txtcolor : str
@@ -412,10 +425,10 @@ def saveFigProbaMinMax(pmin, pmax, filename, bgcol=None, txtcolor="Black"):
   """
   fig = probaMinMaxH(pmin, pmax, txtcolor=txtcolor)
 
-  if bgcol is None:
+  if bgcolor is None:
     fc = gum.config["notebook", "figure_facecolor"]
   else:
-    fc = bgcol
+    fc = bgcolor
 
   fig.savefig(filename, bbox_inches='tight', transparent=False, facecolor=fc,
               pad_inches=0.05, dpi=fig.dpi, format=gum.config["notebook", "graph_format"])
